@@ -1,21 +1,20 @@
 from jijcloud.sampler import JijCloudSampler
 
-
 class JijGPUSASampler(JijCloudSampler):
     hardware = 'gpu'
     algorithm = 'sa'
 
     def sample(self, bqm,
                beta_min=None, beta_max=None,
-               num_reads=1, mc_steps=100,
-               timeout=None):
+               num_reads=1, num_sweeps=100,
+               timeout=None, sync=True):
         """sample ising
         Args:
             bqm (:obj:`dimod.BinaryQuadraticModel`): Binary quadratic model.
             beta_min (float, optional): minimum beta (initial beta in SA).
             beta_max (float, optional): maximum beta (final beta in SA).
             num_reads (int, optional): number of samples. Defaults to 1.
-            mc_steps (int, optional): number of MonteCarlo steps.
+            num_sweeps (int, optional): number of MonteCarlo steps.
             timeout (float optional): number of timeout for post request. Defaults to None. 
         Returns:
             dimod.SampleSet: store minimum energy samples
@@ -27,7 +26,8 @@ class JijGPUSASampler(JijCloudSampler):
                 raise ValueError('beta_min < beta_max')
 
         return super().sample(
-            bqm, num_reads, mc_steps,
+            bqm, num_reads, num_sweeps,
             beta_min=beta_min, beta_max=beta_max,
-            timeout=timeout
+            timeout=timeout,
+            sync=sync
         )
